@@ -101,10 +101,10 @@ class Activity(models.Model):
         """
         obj = self.content_object
         try:
-            image = obj.get_activity_image()
+            image = obj.get_image()
         except AttributeError:
             try:
-                image = obj.content_object.get_activity_image()
+                image = obj.content_object.get_image()
             except:
                 return None
         try:
